from autohandshake.src import (
    # main classes
    HandshakeSession,
    HandshakeBrowser,

    # pages
    AccessRequestPage,
    AppointmentCalendarPage,
    InsightsPage,
    AppointmentTypesListPage,
    AppointmentTypePage,
    MajorSettingsPage,
    FileType,
    RequestStatus
)


name = "autohandshake"
